"""`biblescrapeway` tool for scraping bible verses from the web
"""

from .scraper import scrap, Verse
from . import errors
from . import reference
from . import cli


__author__ = "Jonathan D B Van Schenck"
